package Bundle::Locale::CLDR::Outlyingoceania;

use version;

our $VERSION = version->declare('v0.44.0');

=head1 NAME

Bundle::Locale::CLDR::Outlyingoceania

=head1 CONTENTS

Locale::CLDR::Locales::En::Latn::Dg 0.44.0

Locale::CLDR::Locales::En::Latn::001 0.44.0


=cut

1;

